#if !defined(LKT_CONFIG_H__)
#define LKT_CONFIG_H__

#if defined(__cplusplus)
extern "C" {
#endif

#include <lektor/database.h>
#include <lektor/common.h>

/* Forward definition of the lkt_state structure */
struct lkt_state;

/* The default configuration, stored as a string */
#define section(sct)        "\n[" sct "]\n"
#define value(key, val)     key " = " val "\n"
#define value_opt(key, val) key " = " val " ; Optional value\n"
#define comment(...)        "; " __VA_ARGS__ "\n"
static const char *const lkt_default_config_file =
#include <lektor/internal/config.def>
    ;
#undef comment
#undef value
#undef value_opt
#undef section

/* Try to open the config file `maybe_conf` or find the one to use (see conf
 * file priorities). If no config file is found, one is created at the user
 * level. Returns 0 on success, 1 on failure. Note that the `maybe_conf` buffer
 * of length `maybe_conf_len` will be used to store the used config file path. */
int config_open(lkt_db *db, char *maybe_conf, size_t maybe_conf_len);

/* Prints the default config file. */
void config_default(FILE *output);

/* Manipulate Environment Variables */
#define env_set(var, val) setenv(var, val, 1)
#define env_get           getenv

/* Handle everything for a hook */
void config_handle_hook(lkt_db *db, const char *hook_name);

#if defined(__cplusplus)
}
#endif
#endif /* LKT_CONFIG_H__ */
