#if !defined(LKT_STACK_H__)
#define LKT_STACK_H__

#if defined(__cplusplus)
extern "C" {
#endif

#include <stddef.h>

struct stack {
    volatile void **contents;
    volatile size_t size;
    volatile size_t len;
};

/* Create a new stack. Can't fail because it will avort on out of memory or
 * invalid parameter. */
void stack_new(struct stack *ret);

/* Free a stack */
void stack_free(struct stack *lst);

/* Check if a stack is empty, return 1 if it is empty or invalid, 0 otherwise. */
int stack_empty(struct stack *lst);

/* Push an item to the stack. If it failed (incorrect lst parameter or out of
 * memory), will abort. */
void stack_push(struct stack *lst, void *item);

/* Pop an item from the stack, if the pointer was retreived with malloc, you
 * must free it yourself. If no item is available will return 1, and return 0
 * uppon successfull pop. */
int stack_pop(struct stack *lst, void **item);

/* Peek the head of the stack, don't free the pointer if it was allocated! */
int stack_head(struct stack *lst, void **item);

#if defined(__cplusplus)
}
#endif
#endif /* LKT_STACK_H__ */
